<a id="packages.open_aea.protocols.signing.tests.test_signing_dialogues"></a>

# packages.open`_`aea.protocols.signing.tests.test`_`signing`_`dialogues

Test dialogues module for signing protocol.

<a id="packages.open_aea.protocols.signing.tests.test_signing_dialogues.TestDialoguesSigning"></a>

## TestDialoguesSigning Objects

```python
class TestDialoguesSigning(BaseProtocolDialoguesTestCase)
```

Test for the 'signing' protocol dialogues.

<a id="packages.open_aea.protocols.signing.tests.test_signing_dialogues.TestDialoguesSigning.ROLE_FOR_THE_FIRST_MESSAGE"></a>

#### ROLE`_`FOR`_`THE`_`FIRST`_`MESSAGE

CHECK

<a id="packages.open_aea.protocols.signing.tests.test_signing_dialogues.TestDialoguesSigning.make_message_content"></a>

#### make`_`message`_`content

```python
def make_message_content() -> dict
```

Make a dict with message contruction content for dialogues.create.

